==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/sr/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "овог квартала",
	"field-quarter-short-relative+1": "следећег квартала",
	"field-tue-relative+-1": "прошлог уторка",
	"field-year": "година",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "минут",
	"field-tue-narrow-relative+0": "у уто",
	"field-tue-narrow-relative+1": "следећег уто",
	"field-thu-short-relative+0": "у чет",
	"field-thu-short-relative+1": "следећег чет",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"field-day-relative+2": "прекосутра",
	"field-wed-narrow-relative+-1": "прошле сре",
	"field-year-narrow": "г.",
	"field-tue-relative+0": "у уторак",
	"field-tue-relative+1": "следећег уторка",
	"field-second-short": "сек.",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d. MMM",
	"dayPeriods-format-abbr-am": "пре подне",
	"field-week-relative+0": "ове недеље",
	"field-month-relative+0": "овог месеца",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+1": "следећег месеца",
	"field-sun-narrow-relative+0": "у нед",
	"field-mon-short-relative+0": "у пон",
	"field-sun-narrow-relative+1": "следеће нед",
	"field-mon-short-relative+1": "следећег пон",
	"field-second-relative+0": "сада",
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"months-standAlone-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"dayPeriods-standAlone-abbr-pm": "по подне",
	"field-month-short": "мес.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "d.M.y. GGGGG",
	"field-day": "дан",
	"field-year-relative+-1": "прошле године",
	"dayPeriods-format-wide-am": "пре подне",
	"field-sat-short-relative+-1": "прошле суб",
	"field-hour-relative+0": "овог сата",
	"dateFormatItem-yyyyMEd": "E, d.M.y. GGGGG",
	"field-wed-relative+-1": "прошле среде",
	"field-sat-narrow-relative+-1": "прошле суб",
	"field-second": "секунд",
	"days-standAlone-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"dayPeriods-standAlone-wide-pm": "по подне",
	"dateFormat-long": "d. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "квартал",
	"field-week-short": "нед.",
	"quarters-standAlone-wide": [
		"први квартал",
		"други квартал",
		"трећи квартал",
		"четврти квартал"
	],
	"days-format-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"field-tue-short-relative+0": "у уто",
	"field-tue-short-relative+1": "следећег уто",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "месец",
	"field-day-narrow": "д.",
	"field-minute-short": "мин.",
	"field-dayperiod": "пре подне/по подне",
	"field-sat-short-relative+0": "у суб",
	"field-sat-short-relative+1": "следеће суб",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d.MM.y. G",
	"dateFormatItem-yyyyMMMM": "MMMM y. G",
	"quarters-standAlone-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"dayPeriods-format-abbr-pm": "по подне",
	"dateFormatItem-yyyyM": "M.y. GGGGG",
	"field-second-narrow": "с.",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"field-year-short": "год.",
	"months-format-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-quarter-relative+-1": "прошлог квартала",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dayPeriods-standAlone-narrow-am": "пре подне",
	"days-format-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "по подне",
	"field-sat-relative+-1": "прошле суботе",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "сат",
	"months-format-wide": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"field-month-relative+-1": "прошлог месеца",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "кв.",
	"field-sat-narrow-relative+0": "у суб",
	"field-fri-relative+0": "у петак",
	"field-sat-narrow-relative+1": "следеће суб",
	"field-fri-relative+1": "следећег петка",
	"field-sun-short-relative+0": "у нед",
	"field-sun-short-relative+1": "следеће нед",
	"field-week-relative+-1": "прошле недеље",
	"field-quarter-short-relative+-1": "прошлог квартала",
	"months-format-abbr": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"field-quarter-relative+0": "овог квартала",
	"field-minute-relative+0": "овог минута",
	"field-quarter-relative+1": "следећег квартала",
	"field-wed-short-relative+-1": "прошле сре",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-thu-short-relative+-1": "прошлог чет",
	"days-standAlone-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "прошлог пон",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "прошлог чет",
	"field-tue-narrow-relative+-1": "прошлог уто",
	"dateFormatItem-yyyy": "y. G",
	"dayPeriods-standAlone-narrow-pm": "по подне",
	"field-wed-short-relative+0": "у сре",
	"months-standAlone-wide": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"field-wed-short-relative+1": "следеће сре",
	"field-sun-relative+-1": "прошле недеље",
	"days-standAlone-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-hm": "hh.mm a",
	"field-weekday": "дан у недељи",
	"field-quarter-narrow-relative+0": "овог квартала",
	"field-sat-relative+0": "у суботу",
	"field-quarter-narrow-relative+1": "следећег квартала",
	"dateFormatItem-h": "hh a",
	"field-sat-relative+1": "следеће суботе",
	"months-standAlone-abbr": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"dateFormatItem-MEd": "E, d.M.",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "у чет",
	"field-thu-narrow-relative+1": "следећег чет",
	"field-sun-narrow-relative+-1": "прошле нед",
	"field-mon-short-relative+-1": "прошлог пон",
	"field-thu-relative+0": "у четвртак",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-hms": "hh.mm.ss a",
	"field-fri-short-relative+-1": "прошлог пет",
	"field-thu-relative+-1": "прошлог четвртка",
	"field-week": "недеља",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"први квартал",
		"други квартал",
		"трећи квартал",
		"четврти квартал"
	],
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "у сре",
	"field-wed-narrow-relative+1": "следеће сре",
	"field-quarter-narrow-relative+-1": "прошлог квартала",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"field-fri-short-relative+0": "у пет",
	"field-fri-short-relative+1": "следећег пет",
	"days-standAlone-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"field-hour-short": "ч.",
	"quarters-format-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"field-month-narrow": "м.",
	"field-hour-narrow": "ч.",
	"field-fri-narrow-relative+-1": "прошлог пет",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-fri-relative+-1": "прошлог петка",
	"field-tue-short-relative+-1": "прошлог уто",
	"field-minute-narrow": "мин.",
	"days-format-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"field-mon-narrow-relative+0": "у пон",
	"field-mon-narrow-relative+1": "следећег пон",
	"field-zone": "временска зона",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-quarter-narrow": "кв.",
	"field-sun-short-relative+-1": "прошле нед",
	"field-day-relative+-1": "јуче",
	"dayPeriods-standAlone-abbr-am": "пре подне",
	"field-day-relative+-2": "прекјуче",
	"days-format-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"field-sun-relative+0": "у недељу",
	"field-sun-relative+1": "следеће недеље",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "д.",
	"field-week-narrow": "н.",
	"field-era": "ера",
	"field-fri-narrow-relative+0": "у пет",
	"field-fri-narrow-relative+1": "следећег пет",
	"dayPeriods-standAlone-wide-am": "пре подне"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/sr/persian.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "овог квартала",
	"field-quarter-short-relative+1": "следећег квартала",
	"field-tue-relative+-1": "прошлог уторка",
	"field-year": "година",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"field-minute": "минут",
	"field-month-narrow-relative+-1": "прошлог м.",
	"field-tue-narrow-relative+0": "у уто",
	"field-tue-narrow-relative+1": "следећег уто",
	"field-thu-short-relative+0": "у чет",
	"field-day-short-relative+-1": "јуче",
	"field-thu-short-relative+1": "следећег чет",
	"field-day-relative+0": "данас",
	"field-day-short-relative+-2": "прекјуче",
	"field-day-relative+1": "сутра",
	"field-week-narrow-relative+0": "ове н.",
	"field-day-relative+2": "прекосутра",
	"field-week-narrow-relative+1": "следеће н.",
	"field-wed-narrow-relative+-1": "прошле сре",
	"dateFormatItem-EBhms": "E hh:mm:ss B",
	"field-year-narrow": "г.",
	"field-era-short": "ера",
	"field-year-narrow-relative+0": "ове г.",
	"field-tue-relative+0": "у уторак",
	"field-year-narrow-relative+1": "следеће г.",
	"field-tue-relative+1": "следећег уторка",
	"field-weekdayOfMonth": "дан у месецу",
	"field-second-short": "сек.",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "дан у месецу",
	"dayPeriods-format-abbr-am": "пре подне",
	"field-week-relative+0": "ове недеље",
	"field-month-relative+0": "овог месеца",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+1": "следећег месеца",
	"field-sun-narrow-relative+0": "у нед",
	"field-mon-short-relative+0": "у пон",
	"field-sun-narrow-relative+1": "сл. нед.",
	"field-mon-short-relative+1": "следећег пон",
	"field-second-relative+0": "сада",
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"months-standAlone-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-weekOfMonth": "недеља у месецу",
	"dayPeriods-standAlone-abbr-pm": "по подне",
	"field-month-short": "мес.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "d.M.y. GGGGG",
	"field-day": "дан",
	"field-dayOfYear-short": "дан у год.",
	"field-year-relative+-1": "прошле године",
	"dayPeriods-format-wide-am": "пре подне",
	"field-sat-short-relative+-1": "прошле суб",
	"field-hour-relative+0": "овог сата",
	"dateFormatItem-yyyyMEd": "E, d.M.y. GGGGG",
	"field-wed-relative+-1": "прошле среде",
	"field-sat-narrow-relative+-1": "прошле суб",
	"field-second": "секунд",
	"days-standAlone-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"dayPeriods-standAlone-wide-pm": "по подне",
	"dateFormatItem-Ehms": "E hh:mm:ss a",
	"dateFormat-long": "d. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "квартал",
	"field-week-short": "нед.",
	"field-day-narrow-relative+0": "данас",
	"field-day-narrow-relative+1": "сутра",
	"field-day-narrow-relative+2": "прекосутра",
	"quarters-standAlone-wide": [
		"први квартал",
		"други квартал",
		"трећи квартал",
		"четврти квартал"
	],
	"days-format-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"field-tue-short-relative+0": "у уто",
	"field-tue-short-relative+1": "следећег уто",
	"field-month-short-relative+-1": "прошлог мес.",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "месец",
	"field-day-narrow": "д.",
	"field-minute-short": "мин.",
	"field-dayperiod": "пре подне/по подне",
	"field-sat-short-relative+0": "у суб",
	"field-sat-short-relative+1": "следеће суб",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d.MM.y. G",
	"dateFormatItem-yyyyMMMM": "MMMM y. G",
	"quarters-standAlone-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"dayPeriods-format-abbr-pm": "по подне",
	"dateFormatItem-yyyyM": "M.y. GGGGG",
	"field-second-narrow": "с.",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"field-day-narrow-relative+-1": "јуче",
	"field-year-short": "год.",
	"field-day-narrow-relative+-2": "прекјуче",
	"months-format-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-quarter-relative+-1": "прошлог квартала",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"field-dayperiod-narrow": "пре подне/по подне",
	"dayPeriods-standAlone-narrow-am": "пре подне",
	"field-week-narrow-relative+-1": "прошле н.",
	"days-format-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "по подне",
	"field-dayOfYear": "дан у години",
	"field-sat-relative+-1": "прошле суботе",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "сат",
	"months-format-wide": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"field-month-relative+-1": "прошлог месеца",
	"field-quarter-short": "кв.",
	"field-sat-narrow-relative+0": "у суб",
	"field-fri-relative+0": "у петак",
	"field-sat-narrow-relative+1": "следеће суб",
	"field-fri-relative+1": "следећег петка",
	"dateFormatItem-EBhm": "E hh:mm B",
	"field-month-narrow-relative+0": "овог м.",
	"field-month-narrow-relative+1": "следећег м.",
	"field-sun-short-relative+0": "у нед",
	"field-sun-short-relative+1": "сл. нед.",
	"field-week-relative+-1": "прошле недеље",
	"field-quarter-short-relative+-1": "прошлог квартала",
	"dateFormatItem-Ehm": "E hh:mm a",
	"months-format-abbr": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"field-quarter-relative+0": "овог квартала",
	"field-minute-relative+0": "овог минута",
	"field-quarter-relative+1": "следећег квартала",
	"field-wed-short-relative+-1": "прошле сре",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-thu-short-relative+-1": "прошлог чет",
	"field-year-narrow-relative+-1": "прошле г.",
	"days-standAlone-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "прошлог пон",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "прошлог чет",
	"field-tue-narrow-relative+-1": "прошлог уто",
	"field-weekOfMonth-short": "нед. у мес.",
	"dateFormatItem-yyyy": "y. G",
	"dayPeriods-standAlone-narrow-pm": "по подне",
	"field-wed-short-relative+0": "у сре",
	"months-standAlone-wide": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"field-wed-short-relative+1": "следеће сре",
	"field-sun-relative+-1": "прошле недеље",
	"days-standAlone-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-hm": "hh:mm a",
	"field-weekday": "дан у недељи",
	"field-day-short-relative+0": "данас",
	"field-quarter-narrow-relative+0": "овог квартала",
	"field-sat-relative+0": "у суботу",
	"field-day-short-relative+1": "сутра",
	"field-quarter-narrow-relative+1": "следећег квартала",
	"field-sat-relative+1": "следеће суботе",
	"field-day-short-relative+2": "прекосутра",
	"field-week-short-relative+0": "ове нед.",
	"field-week-short-relative+1": "следеће нед.",
	"months-standAlone-abbr": [
		"Фаравадин",
		"Ордибехешт",
		"Кордад",
		"Тир",
		"Мордад",
		"Шахривар",
		"Мехр",
		"Абан",
		"Азар",
		"Деј",
		"Бахман",
		"Есфанд"
	],
	"field-dayOfYear-narrow": "дан у год.",
	"field-month-short-relative+0": "овог мес.",
	"field-month-short-relative+1": "следећег мес.",
	"field-weekdayOfMonth-short": "дан у месецу",
	"dateFormatItem-MEd": "E, d.M.",
	"field-zone-narrow": "временска зона",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "у чет",
	"field-thu-narrow-relative+1": "следећег чет",
	"field-sun-narrow-relative+-1": "пр. нед.",
	"field-mon-short-relative+-1": "прошлог пон",
	"field-thu-relative+0": "у четвртак",
	"field-thu-relative+1": "следећег четвртка",
	"field-fri-short-relative+-1": "прошлог пет",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-thu-relative+-1": "прошлог четвртка",
	"field-week": "недеља",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"први квартал",
		"други квартал",
		"трећи квартал",
		"четврти квартал"
	],
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "у сре",
	"field-wed-narrow-relative+1": "следеће сре",
	"field-quarter-narrow-relative+-1": "прошлог квартала",
	"field-year-short-relative+0": "ове год.",
	"field-dayperiod-short": "пре подне/по подне",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"field-year-short-relative+1": "следеће год.",
	"field-fri-short-relative+0": "у пет",
	"field-fri-short-relative+1": "следећег пет",
	"days-standAlone-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"field-week-short-relative+-1": "прошле нед.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"field-hour-short": "ч.",
	"field-zone-short": "временска зона",
	"quarters-format-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"field-month-narrow": "м.",
	"field-hour-narrow": "ч.",
	"field-fri-narrow-relative+-1": "прошлог пет",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-era-narrow": "ера",
	"field-fri-relative+-1": "прошлог петка",
	"dateFormatItem-Bhms": "hh:mm:ss B",
	"field-tue-short-relative+-1": "прошлог уто",
	"field-minute-narrow": "мин.",
	"days-format-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"field-mon-narrow-relative+0": "у пон",
	"field-mon-narrow-relative+1": "следећег пон",
	"field-year-short-relative+-1": "прошле год.",
	"field-zone": "временска зона",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "нед. у мес.",
	"field-weekday-narrow": "дан у недељи",
	"field-quarter-narrow": "кв.",
	"field-sun-short-relative+-1": "пр. нед.",
	"field-day-relative+-1": "јуче",
	"dayPeriods-standAlone-abbr-am": "пре подне",
	"field-day-relative+-2": "прекјуче",
	"field-weekday-short": "дан у недељи",
	"days-format-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-Bhm": "hh:mm B",
	"field-sun-relative+0": "у недељу",
	"field-sun-relative+1": "следеће недеље",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "д.",
	"field-week-narrow": "н.",
	"field-era": "ера",
	"field-fri-narrow-relative+0": "у пет",
	"field-fri-narrow-relative+1": "следећег пет",
	"dayPeriods-standAlone-wide-am": "пре подне"
}
//end v1.x content
);
